from .__cls_aide_dao_model_column__ import __cls_aide_dao_model_column__
from .__cls_aide_dao_db_types__ import __cls_aide_dao_db_types__


class __cls_aide_dao_model_base__:
    def __init__(self):
        self.__dict_all = {}

        self.__db_type = None

        self.schema_name = None

        self.table_name = None

        self.table = f'{self.schema_name}.{self.table_name}'

        self.all_columns = f"{self.table}.*"

    def set_base(self, db_type, schema_name, table_name):
        self.__dict_all = {}

        self.set_db_type(db_type)

        self.schema_name = f'"{schema_name}"'

        self.table_name = f'"{table_name}"'

        self.table = f'{self.schema_name}.{self.table_name}'

        self.all_columns = f"{self.table}.*"

    @property
    def db_type(self):
        return self.__db_type

    def set_db_type(self, db_type: str):
        self.__db_type = __cls_aide_dao_db_types__.get_db_type(db_type)

    def column(self, new_pure_col_name: str,
               new_mask_name: str = None,
               new_map_code: str = None,
               new_value=None,
               new_default_value=None,
               is_key: bool = False,
               not_null: bool = False, ):
        return __cls_aide_dao_model_column__(new_pure_schema_name=self.schema_name,
                                             new_pure_table_name=self.table_name,
                                             new_pure_col_name=new_pure_col_name,
                                             new_mask_name=new_mask_name,
                                             new_map_code=new_map_code,
                                             new_value=new_value,
                                             new_default_value=new_default_value,
                                             is_key=is_key,
                                             not_null=not_null,
                                             dict_all=self.__dict_all,
                                             db_type=self.__db_type)

    @property
    def all(self):
        return self.__dict_all

    @property
    def dict_map_code(self):
        return {self.__dict_all[column_name]["map_code"]: column_name for column_name in self.__dict_all
                if self.__dict_all[column_name]["map_code"] is not None}

    # # 动态添加属性,可行，但是在IDE里无法自动提示和补全还有检测
    # def add_column(self, column_name):
    #     column = column_model(self.table, column_name, db_type=self.db_type)
    #     setattr(cls_dao_model_base, column_name, column)



class __cls_aide_dao_db_types__:
    class _cls_db_type:
        def __init__(self, type_name: str, list_alias=None):

            if list_alias is None:
                list_alias = [type_name]
            elif isinstance(list_alias, list):
                list_alias.append(type_name)
            else:
                list_alias = list_alias.splite(",")

            self.__dict = {"type_name": type_name,
                           "aliases": list_alias,
                           "sql": None}

        @property
        def dict(self):
            return self.__dict

        @property
        def type_name(self):
            return self.__dict["type_name"]

        @property
        def aliases(self):
            return self.__dict["aliases"]

        @property
        def sql(self):
            return self.__dict["sql"]

        def set_sql(self, new_sql):
            self.__dict["sql"] = new_sql

    DB2 = _cls_db_type(type_name="DB2")
    PostgreSQL = _cls_db_type(type_name="PostgreSQL", list_alias=['pgs', 'postgres'])
    SQLite = _cls_db_type(type_name="SQLite")

    @classmethod
    def get_db_type(cls, db_alias: str):
        if db_alias is None:
            return cls.PostgreSQL.type_name
        else:
            for attr in dir(cls):
                inst = getattr(cls, attr)
                if isinstance(inst, cls._cls_db_type):
                    if db_alias.upper() in [alias.upper() for alias in inst.aliases]:
                        return inst.type_name



class __cls_aide_dao_action__:
    def __init__(self, table_name: str):
        self._table = table_name
        self._dict_select = {}
        self._dict_insert_update = {}
        self.sql_where = ""

    @staticmethod
    def chk_col(col: str):
        col = col.replace('"', '')
        col = f'"{col}"'
        col = col.replace('.', '"."')
        return col

    def get_value(self, key):
        return self._dict_insert_update[key]

    def where(self, sql_where):
        self.sql_where = " WHERE " + sql_where

    def and_where(self, sql_where):
        self.sql_where = self.sql_where + " AND " + sql_where

    def or_where(self, sql_where):
        self.sql_where = self.sql_where + " OR " + sql_where

    def select(self, data: str, new_value: str = None):
        column = data

        if isinstance(new_value, int):
            pass
        elif new_value is None:
            new_value = None
        else:
            new_value = new_value.replace("'", "''")
            new_value = f"'{new_value}'"

        value = new_value

        self._dict_select[column] = value

    def add(self, data: str, new_value: str = None):

        if data.find("=") > 0:
            split_index = data.find("=")
            column = data[:split_index]
            value = data[split_index + 1:]
        else:
            column = data
            if isinstance(new_value, int):
                pass
            elif new_value is None:
                new_value = 'NULL'
            else:
                new_value = new_value.replace("'", "''")
                new_value = f"'{new_value}'"

            value = new_value

        self._dict_insert_update[column] = value

    def update(self, data: str, new_value: str = None):
        self.add(data=data, new_value=new_value)

    @property
    def SQL_add(self):

        sql_columns = None

        sql_values = None

        for key in self._dict_insert_update:

            value = self._dict_insert_update[key]

            column = self.chk_col(key)

            if sql_columns is None:
                sql_columns = column
                sql_values = value
            else:
                sql_columns = f'{sql_columns},{column}'
                sql_values = f"{sql_values},{value}"

        sql = f"INSERT " \
              + f" INTO {self._table}" \
              + f" ({sql_columns}) VALUES ({sql_values})"

        self._dict_insert_update = {}

        return sql

    @property
    def SQL_update(self):
        sql_update_item = None

        for key in self._dict_insert_update:

            value = self._dict_insert_update[key]

            column = self.chk_col(key)

            if sql_update_item is None:
                sql_update_item = f"{column}={value}"
            else:
                sql_update_item = f'{sql_update_item},f"{column}={value}"'

        sql = f"UPDATE " \
              + f" {self._table} SET {sql_update_item}" \
              + self.sql_where

        self._dict_insert_update = {}

        return sql

    @property
    def SQL_select(self):
        sql_select_item = None

        for key in self._dict_select:

            value = self._dict_select[key]

            column = self.chk_col(key)

            if value in [None, '', ]:
                pass
            else:
                column = f'{column} AS "{value}"'

            if sql_select_item is None:
                sql_select_item = column
            else:
                sql_select_item = f'{sql_select_item},{column}'

        sql = f"SELECT {sql_select_item}" \
              + f" FROM {self._table}" \
              + self.sql_where

        self._dict_select = {}

        return sql



class __cls_aide_dao_model_column__:
    def __init__(self,
                 new_pure_schema_name: str,
                 new_pure_table_name: str,
                 new_pure_col_name: str,
                 new_mask_name: str = None,
                 new_map_code: str = None,
                 new_value=None,
                 new_default_value=None,
                 is_key: bool = False,
                 not_null: bool = False,
                 dict_all: dict = None,
                 db_type: str = None):

        self.__db_type = db_type

        # if new_pure_db_table_name.find('"') == 2:
        #     self.__my_pure_db_table_name = new_pure_db_table_name.replace('"', '')
        # else:
        #     self.__my_pure_db_table_name = new_pure_db_table_name

        self.__my_pure_schema_name = new_pure_schema_name.replace('"', '')

        self.__my_pure_table_name = new_pure_table_name.replace('"', '')

        # if new_pure_col_name.find('"') == 2:
        #     self.__my_pure_col_name = new_pure_col_name.replace('"', '')
        # else:
        #     self.__my_pure_col_name = new_pure_col_name

        self.__my_pure_col_name = new_pure_col_name.replace('"', '')

        if new_mask_name is None:
            self.__my_mask_code = self.__my_pure_col_name
        else:
            self.__my_mask_code = new_mask_name

        if new_map_code is None:
            self.__my_map_code = self.__my_pure_col_name
        else:
            self.__my_map_code = new_map_code

        if new_default_value is None:
            self.__my_default_value = None
        else:
            self.__my_default_value = self.__reform_str_value_sql(new_default_value)

        self.__my_value = self.__reform_str_value_sql(new_value)

        self.__is_key = is_key

        if self.__is_key is True:
            self.__not_null = self.__is_key
        else:
            self.__not_null = not_null

        if dict_all is None:
            pass
        else:
            dict_all[self.__my_pure_col_name] = {"is_key": self.__is_key,
                                                 "not_null": self.__not_null,
                                                 "default_value": self.__my_default_value,
                                                 "map_code": self.__my_map_code,
                                                 "mask_name": self.__my_mask_code,
                                                 "value": self.__my_value}

    @property
    def name_db_full(self):
        return f'"{self.__my_pure_schema_name}"."{self.__my_pure_table_name}"."{self.__my_pure_col_name}"'

    @property
    def name_db(self):
        return f'"{self.__my_pure_col_name}"'

    @property
    def name(self):
        return self.__my_pure_col_name

    @property
    def value(self):
        return self.__my_value

    def set_value(self, my_value, dict_all: dict = None, is_key: bool = False):
        self.__my_value = self.__reform_str_value_sql(my_value)

        if is_key is False:
            pass
        else:
            self.__is_key = is_key

        if dict_all is None:
            pass
        else:
            dict_all[self.__my_pure_col_name]["value"] = self.__my_value
            dict_all[self.__my_pure_col_name]["is_key"] = self.__is_key

    @property
    def is_key(self):
        return self.__my_value

    def set_is_key(self, my_value, dict_all: dict = None):
        self.__my_value = self.__reform_str_value_sql(my_value)
        if dict_all is None:
            pass
        else:
            dict_all[self.__my_pure_col_name]["is_key"] = self.__my_value

    @property
    def mask_code(self):
        return self.__my_mask_code

    def set_mask_code(self, my_code):
        self.__my_mask_code = my_code

    @property
    def map_code(self):
        return self.__my_map_code

    def set_map_code(self, my_code):
        self.__my_map_code = my_code

    def default_value(self):
        return self.__my_default_value

    def set_default_value(self, new_default_value):
        self.__my_default_value = self.__reform_str_value(new_default_value)

    # def set(self, my_value):
    #     if isinstance(my_value, type(None)) is True:
    #         my_value = str('NULL')
    #     elif isinstance(my_value, int) is True:
    #         pass
    #     elif isinstance(my_value, dict) is True:
    #         my_value = json.dumps(my_value)
    #         my_value = f"'{my_value}'"
    #     elif my_value[0:2] == "@#":
    #         my_value = my_value[2:len(my_value)]
    #     elif (isinstance(my_value, str) is True and my_value.isdigit() is False) or my_value == '':
    #         my_value = my_value.replace("'", "''")
    #         my_value = "'" + my_value + "'"
    #     else:
    #         my_value = str(my_value)
    #
    #     col = self.name_db_full
    #     val = my_value
    #     my_dict = {col: val}
    #     return my_dict

    # def insert(self, my_value):
    #     return self.set(my_value)
    #
    # def insert_sql(self, my_sql):
    #     return self.set(f"@#{my_sql}")
    #
    # def insert_by_map_code(self, my_dict: dict, level_2_key: str = None):
    #     if my_dict.__contains__(self.map_code):
    #         my_value = my_dict[self.map_code]
    #         if isinstance(my_value, dict) and level_2_key is not None:
    #             if my_value.__contains__(level_2_key):
    #                 my_value = my_value[level_2_key]
    #             else:
    #                 pass
    #         else:
    #             pass
    #     else:
    #         my_value = None
    #     return self.set(my_value)

    ###############################################################
    @staticmethod
    def __reform_str_value_sql(new_value: str):
        if new_value is None:
            return "NULL"
        else:
            if isinstance(new_value, int):
                return new_value
            else:
                if isinstance(new_value, str):
                    if new_value[0:2] == "@#":
                        return new_value[2:]
                    elif new_value[:1] == "'" and new_value[-1:] == "'":
                        return new_value
                    else:
                        return "'" + new_value + "'"
                else:
                    return "'" + str(new_value) + "'"

    @staticmethod
    def __reform_str_value_sub(new_value, force: bool = False):
        if new_value is None:
            return "NULL"
        elif isinstance(new_value, int):
            return new_value
        elif force is True:
            return "'" + new_value + "'"
        elif new_value[:1] == "'" and new_value[-1:] == "'":
            return new_value
        else:
            return "'" + new_value + "'"

    def __reform_str_value2(self, my_value):
        if my_value.find(",") > 0:
            list_my_value = str(my_value).split(",")
            is_correct = True
            for item in list_my_value:
                if item.isalnum():
                    pass
                elif item[:1] == "'" and item[-1:] == "'":
                    pass
                else:
                    is_correct = False

            if is_correct is True:
                pass
            else:
                my_value = self.__reform_str_value_sub(my_value)
        else:
            my_value = self.__reform_str_value_sub(my_value)
        return my_value

    @staticmethod
    def __reform_str_value(my_value):
        if isinstance(my_value, str):
            if my_value == "":
                my_value = "'" + my_value + "'"
            else:
                if my_value[0] == "'" and my_value[-1] == "'":
                    max_len = len(my_value)
                    max_len_1 = max_len - 1
                    my_value = my_value[0] + my_value[1:max_len_1].replace("'", "''") + my_value[-1]
                else:
                    my_value = my_value.replace("'", "''")
                    my_value = "'" + my_value + "'"
        else:
            my_value = str(my_value)
        return my_value

    # Chr（10）：ASCII码中的换行键，相当于vbLF。
    # Chr（13）：ASCII码中的回车键，相当于vbCR。
    next_row = ' CHR(13)||CHR(10) '

    next_two_row = ' CHR(10)||CHR(13) '

    @property
    def timestamp(self):
        # it is the same in DB2,PostgreSQL
        return "CURRENT_TIMESTAMP"

    @property
    def timestamp_gmt0(self):
        # SQL_DB2="TIMESTAMP (CURRENT TIMESTAMP - (CURRENT TIMEZONE * 0.36)SECONDS)"
        sql_DB2 = "CURRENT_TIMESTAMP-CURRENT_TIMEZONE"
        sql_PostgreSQL = "CURRENT_TIMESTAMP"

        __dict = {"DB2": sql_DB2,
                  "POSTGRES": sql_PostgreSQL}

        return "__dict[self.__db_type]"

    @property
    def date_gmt0(self):
        return f"DATE({self.timestamp_gmt0})"

    @staticmethod
    def timestamp_gmt0_char():
        sql_timestamp = "TIMESTAMP (CURRENT TIMESTAMP - (CURRENT TIMEZONE * 0.36)SECONDS)"
        sql_timestamp = "TO_CHAR(" + sql_timestamp + ", 'yyyy-mm-dd hh24:mi:ss.nnnnnn')"
        return sql_timestamp

    def date_gmt0_char(self):
        return "DATE(" + self.timestamp_gmt0_char() + ")"

    def length_BE(self, length: int, trim: bool = True, rm_string: str = "%"):
        sql = None
        if rm_string is None:
            pass
        else:
            sql = f"REPLACE({self.name_db_full},'{rm_string}','')"

        if trim is False:
            sql = f"LENGTH({sql}) >= {length}"
        else:
            sql = f"LENGTH(TRIM({sql})) >= {length}"

        return sql

    @property
    def is_null(self):
        return self.name_db_full + ' IS NULL '

    @property
    def is_not_null(self):
        return self.name_db_full + ' IS NOT NULL '

    def iss(self, my_value):
        return self.name_db_full + ' IS ' + str(my_value)

    def iss_not(self, my_value):
        return self.name_db_full + ' IS NOT ' + str(my_value)

    def append_sql(self, new_sql):
        return self.append(new_sql=new_sql)

    def append(self, new_str: str = None, split_key: str = next_row, new_sql: str = None):

        if split_key is None and new_str is None and new_sql is None:
            return self.name_db_full + ' = ' + self.name_db_full

        new_value = self.name_db_full

        if new_str is None:
            pass
        else:
            new_value = "'" + new_str + "'"

        if new_sql is None:
            pass
        else:
            new_value = new_sql

        sql = f"(CASE WHEN {self.name_db_full} IS NULL " \
              + f" THEN {new_value} " \
              + f" ELSE {self.name_db_full} || {split_key} || {new_value} END)"

        return self.name_db_full + ' = ' + sql

    def equate_sql(self, my_value):
        return self.name_db_full + ' = ' + str(my_value)

    def not_equate_sql(self, my_value):
        return self.name_db_full + ' <> ' + str(my_value)

    def not_equate(self, my_value, match_case: bool = True):
        return self.equate(my_value, match_case=match_case, do_not=True)

    def equate(self, my_value, match_case: bool = True, do_not: bool = False):
        if my_value is None:
            if do_not is True:
                return self.name_db_full + " IS NOT NULL "
            else:
                return self.name_db_full + " IS NULL "
        else:
            if do_not is True:
                operator = " <> "
            else:
                operator = " = "

            if match_case is True:
                left = self.name_db_full
                right = self.__reform_str_value(my_value)
            else:
                left = "UCASE(" + self.name_db_full + ")"
                right = "UCASE(" + self.__reform_str_value(my_value) + ")"

            return left + operator + right

    def equate_ucase(self, my_value):
        if my_value is None:
            return self.name_db_full + " IS NULL "
        else:
            return "UCASE(" + self.name_db_full + ') = UCASE(' + self.__reform_str_value(my_value) + ')'

    @staticmethod
    def to_date_col(my_value):
        return "TO_DATE(" + my_value + " , 'yyyy-mm-dd hh24:mi:ss')"

    @staticmethod
    def to_date_str(my_value):
        return "TO_DATE('" + my_value + "' , 'yyyy-mm-dd hh24:mi:ss')"

    def compare(self, operator, my_value, is_time: bool = False):
        if is_time is True:
            return self.to_date_col(self.name_db_full) + ' ' + operator + ' ' + self.to_date_str(str(my_value))
        else:
            return self.name_db_full + ' ' + operator + ' ' + str(my_value)

    def bigger(self, my_value, is_time: bool = False):
        return self.compare(">", my_value, is_time)

    def bigger_equ(self, my_value, is_time: bool = False):
        return self.compare(">=", my_value, is_time)

    def smaller(self, my_value, is_time: bool = False):
        return self.compare("<", my_value, is_time)

    def smaller_equ(self, my_value, is_time: bool = False):
        return self.compare("<=", my_value, is_time)

    def inn(self, my_value):
        if my_value is None:
            return self.name_db_full + " IS NULL "
        else:
            return self.name_db_full + " IN " + "(" + self.__reform_str_value2(str(my_value)) + ")"

    def inn_sql(self, my_value):
        return self.name_db_full + " IN " + "(" + str(my_value) + ")"

    def not_in_sql(self, my_value):
        return self.name_db_full + " NOT IN " + "(" + str(my_value) + ")"

    def not_in(self, my_value):
        return self.name_db_full + " NOT IN " + "(" + self.__reform_str_value2(my_value) + ")"

    def set_in(self, my_value):
        return self.inn(my_value)

    def like_ucase(self, my_value, inversion: bool = False, do_not: bool = False):
        return self.like_affix(None, my_value, None, ucase=True, inversion=inversion, do_not=do_not)

    # return "UCASE(" + self.name_db_full + ') LIKE UCASE(' + self.__reform_str_value(my_value) + ')'

    def like_affix(self, prefix_key, my_value: str, suffix_key, ucase: bool = False, inversion: bool = False,
                   do_not: bool = False, is_sql: bool = False):

        if do_not is True:
            operator = " NOT LIKE "
        else:
            operator = " LIKE "

        # print("#####", "like_affix")
        if is_sql is True:
            db_value = self.name_db_full
            my_value = my_value
        else:
            if ucase is True:
                db_value = "UCASE(" + self.name_db_full + ")"
                my_value = "UCASE(" + self.__reform_str_value(my_value) + ")"
            else:
                db_value = self.name_db_full
                my_value = self.__reform_str_value(my_value)

        if prefix_key is None and suffix_key is None:
            if inversion is False:
                if my_value[0:1] != "%" and my_value[-2:-1] != "%":
                    my_value = "'%'||" + my_value + "||'%'"
                else:
                    pass
                return db_value + operator + my_value
            else:
                return my_value + operator + "'%'||" + db_value + "||'%'"

        else:
            if prefix_key is None:
                prefix_key = ""
            elif prefix_key[0:1] == "%":
                prefix_key = "'" + prefix_key + "'"
            else:
                prefix_key = "'" + "%" + prefix_key + "'"

            if suffix_key is None:
                suffix_key = ""
            elif suffix_key[:-1] == "%":
                suffix_key = "'" + suffix_key + "'"
            else:
                suffix_key = "'" + suffix_key + "%" + "'"

            if inversion is False:
                return prefix_key + " || " + db_value + " || " + suffix_key \
                       + operator \
                       + prefix_key + " || " + my_value + " || " + suffix_key
            else:
                return prefix_key + " || " + my_value + " || " + suffix_key \
                       + operator \
                       + prefix_key + " || " + db_value + " || " + suffix_key

    def like(self, my_value, ucase: bool = False, inversion: bool = False, do_not: bool = False):
        # print("##### inversion like")
        # print(inversion)
        # print(self.name_db_full)
        # return self.name_db_full + " LIKE " + self.__reform_str_value(my_value)
        return self.like_affix(None, my_value, None, ucase=ucase, inversion=inversion, do_not=do_not)

    def like_prefix(self, prefix_key, my_value, ucase: bool = False, inversion: bool = False, do_not: bool = False):
        # print("##### inversion like_prefix")
        # print(inversion)
        return self.like_affix(prefix_key, my_value, None, ucase=ucase, inversion=inversion, do_not=do_not)

    def like_suffix(self, my_value, suffix_key, ucase: bool = False, inversion: bool = False, do_not: bool = False):
        # print("##### inversion like_suffix")
        # print(inversion)

        return self.like_affix(None, my_value, suffix_key, ucase=ucase, inversion=inversion, do_not=do_not)

    def start_with_sql(self, my_value):
        return "LOCATE(" + my_value + "," + self.name_db_full + ")=1"

    def not_start_with_sql(self, my_value):
        return "LOCATE(" + my_value + "," + self.name_db_full + ")<>1"

    def start_with(self, my_value):
        my_value = self.__reform_str_value(my_value)
        return self.start_with_sql(my_value)

    def not_start_with(self, my_value):
        my_value = self.__reform_str_value(my_value)
        return self.not_start_with_sql(my_value)

    def end_with_sql(self, my_value):
        my_locate = "(LOCATE(" + my_value + "," + self.name_db_full + ")"
        length = my_locate + "-1 + LENGTH(" + my_value + "))=LENGTH(" + self.name_db_full + ")"
        return my_locate + ">0" + " AND " + length

    def end_with(self, my_value):
        my_value = self.__reform_str_value(my_value)
        return self.end_with_sql(my_value)

    # Base
    def contain_sql(self, my_value, do_not: bool = False, case_sensitive: bool = True, split_key: str = None):
        if case_sensitive is True:
            my_value = my_value
            db_value = self.name_db_full
        else:
            my_value = "UCASE(" + my_value + ")"
            db_value = "UCASE(" + self.name_db_full + ")"

        if split_key is not None:
            my_value = f" '{split_key}' ||{my_value} || '{split_key}'"
            db_value = f" '{split_key}' ||{db_value} || '{split_key}'"
        else:
            pass

        if do_not is True:
            return "LOCATE(" + my_value + "," + db_value + ")=0"
        else:
            return "LOCATE(" + my_value + "," + db_value + ")>0"

    def not_contain_sql(self, my_value, case_sensitive: bool = True, split_key: str = None):
        return self.contain_sql(my_value=my_value,
                                do_not=True,
                                case_sensitive=case_sensitive,
                                split_key=split_key)

    def contain(self, my_value, do_not: bool = False, case_sensitive: bool = True, split_key: str = None):
        my_value = self.__reform_str_value(my_value)
        return self.contain_sql(my_value=my_value,
                                do_not=do_not,
                                case_sensitive=case_sensitive,
                                split_key=split_key)

    def not_contain(self, my_value, case_sensitive: bool = True, split_key: str = None):
        return self.contain(my_value=my_value,
                            do_not=True,
                            case_sensitive=case_sensitive,
                            split_key=split_key)

    def has(self, my_value, do_not: bool = False):
        if do_not is False:
            return "',' || " + self.name_db_full + "||','" + " LIKE " \
                   + "','||" + self.__reform_str_value_sql(my_value) + "|| ','"
        else:
            return "',' || " + self.name_db_full + "||','" + " NOT LIKE " \
                   + "','||" + self.__reform_str_value_sql(my_value) + "|| ','"



import zdao


class cls_dao_model(zdao.model):
    # noinspection PyMissingConstructor
    def __init__(self):
        self.set_base(db_type="SQLite", schema_name="SYNC_YOUZHAI", table_name="MYSMSAPP_SMS_RECORD")

        self.MODIFY_LOG = self.column("MODIFY_LOG")

        self.MODIFY_UID = self.column("MODIFY_UID")

        self.MODIFY_TIME_GMT0 = self.column("MODIFY_TIME_GMT0")

        self.CREATE_UID = self.column("CREATE_UID")

        self.CREATE_TIME_GMT0 = self.column("CREATE_TIME_GMT0")

        self.OBSOLETE = self.column("OBSOLETE")

        # ####

        self.ID = self.column("ID")

# class cls_dao_model:
# 	# noinspection PyMissingConstructor
# 	def __init__(self):
# 		pass
#
# 	dict_map_code = {}
#
# 	schema_name = '"SYNC_YOUZHAI"'
#
# 	table_name = '"MYSMSAPP_SMS_RECORD"'
#
# 	table = f'{schema_name}.{table_name}'
#
# 	all_columns = f"{table}.*"
#
# 	MODIFY_LOG = zdao.column(table, "MODIFY_LOG")
#
# 	MODIFY_UID = zdao.column(table, "MODIFY_UID")
#
# 	MODIFY_TIME_GMT0 = zdao.column(table, "MODIFY_TIME_GMT0")
#
# 	CREATE_UID = zdao.column(table, "CREATE_UID")
#
# 	CREATE_TIME_GMT0 = zdao.column(table, "CREATE_TIME_GMT0")
#
# 	OBSOLETE = zdao.column(table, "OBSOLETE")
#
# 	# ####
#
# 	ID = zdao.column(table, "ID")



from setuptools import setup, find_packages
import os

# in windows slash is \,use \\ in code
def next_version():
    file_path = f"{os.getcwd()}\\setup.version"

    f = open(file_path, 'r')

    text = f.read()

    f.close()

    version_now = text.replace("VERSION=", '')

    if version_now in [None, ""]:
        version_next = 1.0
    else:
        version_next = float(version_now) + 0.1

        version_next = round(version_next, 2)

    f = open(file_path, 'w', encoding='utf-8')

    f.write(f"VERSION={version_next}")

    f.close()

    return version_next


setup(
    name="zdao",
    version=next_version(),
    packages=find_packages(),
    install_requires=[],
    author="zhstack",
    author_email="zhstack@163.com",
    description="A useless database access model",
    license="MIT",
    keywords="zdao",
    url="https://github.com/zzt/w-dao.git"
)
